@@ -1,4 +1,5 @@
-﻿define(['libraryBrowser', 'components/categorysyncbuttons', 'cardBuilder', 'dom', 'scrollStyles', 'emby-itemscontainer', 'emby-tabs', 'emby-button'], function (libraryBrowser, categorysyncbuttons, cardBuilder, dom) {
+﻿define(['libraryBrowser', 'components/categorysyncbuttons', 'cardBuilder', 'dom', 'apphost', 'imageLoader', 'scrollStyles', 'emby-itemscontainer', 'emby-tabs', 'emby-button'], function (libraryBrowser, categorysyncbuttons, cardBuilder, dom, appHost, imageLoader) {
+    'use strict';
 
     function enableScrollX() {
         return browserInfo.mobile && AppInfo.enableAppLayouts;
@@ -71,13 +72,21 @@
             var allowBottomPadding = !enableScrollX();
 
             var container = page.querySelector('#resumableItems');
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+            var cardLayout = appHost.preferVisualCards;
+
             cardBuilder.buildCards(result.Items, {
                 itemsContainer: container,
                 preferThumb: true,
                 shape: getThumbShape(),
                 scalable: true,
                 overlayPlayButton: true,
-                allowBottomPadding: allowBottomPadding
+                allowBottomPadding: allowBottomPadding,
+                cardLayout: cardLayout,
+                vibrant: cardLayout && supportsImageAnalysis,
+                showTitle: cardLayout,
+                showYear: cardLayout
             });
 
         });
@@ -161,7 +170,7 @@
 
             var recs = page.querySelector('.recommendations');
             recs.innerHTML = html;
-            ImageLoader.lazyChildren(recs);
+            imageLoader.lazyChildren(recs);
         });
     }
 
